<?php

namespace App\Http\Controllers\Api;

use App\Models\AboutUs;
use App\Services\ApiCommonResponseService;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class AboutUsController extends Controller
{
    private $apiResponse;

    /**
     * Create a new locationservice instatnce
     *
     * @return void
     */
    public function __construct()
    {
        $this->apiResponse = new ApiCommonResponseService();

    }


    public function store(Request $request){

        $about_us_info = AboutUs::all();

        if(!$about_us_info->isEmpty()){
            $code = '204';
            $message = 'First Delete Your Content';

         return $this->apiResponse->error_response($code,$message,'Delete Your Content');

        }


        $validation = Validator::make($request->all(), [

            'title' => 'required',
            'sub_title' => 'required',
            'description' => 'required',
            'contact_number' => 'required',
            'email' => 'required',
            'address' => 'required'
        ]);

        if ($validation->fails()) {

            return $this->apiResponse->error_response('400', 'Validation Error', $validation->errors());
        }

        $create_content_about_us = AboutUs::create([
            'title' => $request->title,
            'sub_title' => $request->sub_title,
            'description' => $request->description,
            'contact_number' => $request->contact_number,
            'email' => $request->email,
            'address' => $request->address
        ]);

        return $this->apiResponse->success_response('200','Content Successfully Created',$create_content_about_us);

    }


    public function update(Request $request){

        $validation = Validator::make($request->all(), [

            'title' => 'required',
            'sub_title' => 'required',
            'description' => 'required',
            'contact_number' => 'required',
            'email' => 'required',
            'address' => 'required'
        ]);

        if ($validation->fails()) {

            return $this->apiResponse->error_response('400', 'Validation Error', $validation->errors());

        }

        $id = AboutUs::first()->id;
        $is_exists = AboutUs::find($id);

        if(!$is_exists){

            $code = '204';
            $message = 'Content Not Found';

            return $this->apiResponse->error_response($code,$message,'Content Not Found');

        }

        $is_exists->update([
            'title' => $request->title,
            'sub_title' => $request->sub_title,
            'description' => $request->description,
            'contact_number' => $request->contact_number,
            'email' => $request->email,
            'address' => $request->address
        ]);


        return $this->apiResponse->success_response('200','Content Successfully Updated',$is_exists);

    }


    public function delete(Request $request){

        $id = AboutUs::first()->id;
        $is_exists = AboutUs::find($id);

        if(!$is_exists){

            $code = '204';
            $message = 'Content Not Found';

            return $this->apiResponse->error_response($code,$message,'Content Not Found');

        }

        $is_exists->delete();

        return $this->apiResponse->success_response('200','Content Successfully Deleted',$is_exists);

    }

    public function index(){

        $all_data_about_us = AboutUs::all();
        return $this->apiResponse->success_response('200','Data Is Ready To Show',$all_data_about_us);

    }

}
