<?php

namespace App\Http\Controllers\Api;

use App\Jobs\SendRegCongratulationMail;
use App\Jobs\SendVideoCongraMail;
use App\Models\Exam;
use App\Models\ExamPaper;
use App\Models\ExamVideo;
use App\Models\Zone;
use App\Services\ApiCommonResponseService;
use App\Services\ExamService;
use App\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;
use Tymon\JWTAuth\Facades\JWTAuth;

class ExamController extends Controller
{
    private $apiResponse , $examService;
    public function __construct()
    {
        $this->apiResponse = new ApiCommonResponseService();
        $this->examService = new ExamService();

    }
    public function store(Request $request){
        $validation = Validator::make($request->all(), [
            'exam_title' => 'required',
            'exam_date' => 'required',
            'exam_start_time' => 'required',
            'exam_end_time' => 'required',
            'exam_description' => 'required',
        ]);
        if ($validation->fails()) {
            return $this->apiResponse->error_response('400', 'Validation Error', $validation->errors());
        }
        $exam = $this->examService->create($request);
        return $this->apiResponse->success_response('200','Content Successfully Updated', $exam);

    }
    public function update(Request $request){
        $validation = Validator::make($request->all(), [
            'exam_title' => 'required',
            'exam_date' => 'required',
            'exam_start_time' => 'required',
            'exam_end_time' => 'required',
            'exam_description' => 'required',
        ]);
        if ($validation->fails()) {
            return $this->apiResponse->error_response('400', 'Validation Error', $validation->errors());
        }
        $exam = $this->examService->update($request);
        return $this->apiResponse->success_response('200','Content Successfully Updated', $exam);

    }
    public function getList(){
        $exams = Exam::all();
        return $this->apiResponse->success_response('200','Content Successfully Updated', $exams);

    }
    public function delete(Request $request){
        $this->examService->delete($request);
        return $this->apiResponse->success_response('200','Content Successfully Deleted', []);

    }
    public function get(Request $request){
        $exam = $this->examService->get($request);
        return $this->apiResponse->success_response('200','Content Successfully Updated', $exam);

    }
    public function submitExamPaper(Request $request){
        $user = JWTAuth::parseToken()->authenticate();
        $exam =  Exam::find($request->exam_id);
        $current_time = Carbon::now();
        $start_time = Carbon::parse($exam->exam_date.' '.$exam->exam_start_time);
        $end_time = Carbon::parse($exam->exam_date.' '.$exam->exam_end_time);
        $end_time->addSeconds(30);
        if(! $current_time->between($start_time, $end_time , true)){
            return $this->apiResponse->error_response('400', 'Time Expired.You cant submit now', 'Time Expired');
        };
        $exam_paper = ExamPaper::where(['exam_id' => $request->exam_id, 'user_id' => $user->id])->first();
        if($exam_paper){
            return $this->apiResponse->error_response('400', 'You submitted your paper before.Cant submit more', 'Time Expired');

        }
        $exam = $this->examService->submitExamPaper($request);
        return $this->apiResponse->success_response('200','Answer Paper Submited Successfully', $exam);

    }
    public function submitExamPaperforAndriod(Request $request){
        $user = JWTAuth::parseToken()->authenticate();
        $request_data =  $request->getContent();
        $request_data = json_decode($request_data);
        $exam =  Exam::find($request_data->exam_id);
        $current_time = Carbon::now();
        $start_time = Carbon::parse($exam->exam_date.' '.$exam->exam_start_time);
        $end_time = Carbon::parse($exam->exam_date.' '.$exam->exam_end_time);
        $end_time->addSeconds(30);
        if(! $current_time->between($start_time, $end_time , true)){
            return $this->apiResponse->error_response('400', 'Time Expired.You cant submit now', 'Time Expired');
        };
        $exam_paper = ExamPaper::where(['exam_id' => $request->exam_id, 'user_id' => $user->id])->first();
        if($exam_paper){
            return $this->apiResponse->error_response('400', 'You submitted your paper before.Cant submit more', 'Time Expired');

        }
        $exam = $this->examService->submitExamPaper($request_data);
        return $this->apiResponse->success_response('200','Answer Paper Submited Successfully', $exam);

    }

    public function submitVideo(Request $request){
        $fileName = $_FILES["file1"]["name"]; // The file name
        $fileTmpLoc = $_FILES["file1"]["tmp_name"]; // File in the PHP tmp folder
        $fileType = $_FILES["file1"]["type"]; // The type of file it is
        $fileSize = $_FILES["file1"]["size"]; // File size in bytes
        $fileErrorMsg = $_FILES["file1"]["error"]; // 0 for false... and 1 for true
        if (!$fileTmpLoc) { // if file not chosen
            echo "ERROR: Please browse for a file before clicking the upload button.";
            exit();
        }
        if(move_uploaded_file($fileTmpLoc, "exam_videos/$fileName".date('Y-m-d H:i:s'))){
            $data['message'] = "Your Video is uploaded";
            $data['name'] = "exam_videos/".$fileName.date('Y-m-d H:i:s');

            return $this->apiResponse->success_response(200,'done', $data);
        } else {
            echo "move_uploaded_file function failed";
        }
    }
    public function submitVideoForAndroid(Request $request){
        $validation = Validator::make($request->all(), [
            'video_type' => 'required',
        ]);
        if ($validation->fails()) {
            return $this->apiResponse->error_response('200', 'Validation Error', $validation->errors());
        }



        $user = JWTAuth::parseToken()->authenticate();
        $e=ExamVideo::where('user_id',$user->id)->first();
        if($e==null)
        {

            $uploaded_data = $this->submitVideo($request);

            ExamVideo::create(array(
                'user_id' => $user->id,
                'video_link' => $uploaded_data->getData()->data->name,
                'video_type' => $request->video_type,
                'exam_id' => 0
            ));
            $user_for_email = User::with('zone')->find($user->id);
            SendVideoCongraMail::dispatch($user_for_email);
            return $this->apiResponse->success_response('200','Video Uploaded Successfully', 'done');

        }
        else
        {
            return $this->apiResponse->error_response('200', 'You Already Upload Your Video','You Already Upload Your Video');
        }

    }
    public function submitVideoData(Request $request){
        $validation = Validator::make($request->all(), [
            'video_type' => 'required',
            'video_link' => 'required',
        ]);
        if ($validation->fails()) {
            return $this->apiResponse->error_response('400', 'Validation Error', $validation->errors());
        }
        $user = JWTAuth::parseToken()->authenticate();
        $exam_video = ExamVideo::where('user_id', $user->id)->first();
        if($exam_video){
            return;
        }
        ExamVideo::create([
           'user_id' => $user->id,
           'video_link' => $request->video_link,
           'video_type' => $request->video_type,
           'exam_id' => $request->exam_id
        ]);

        $user_for_email = User::with('zone')->find($user->id);
        SendVideoCongraMail::dispatch($user_for_email);


    }
    public function submitYoutubeVideoLink(Request $request){
        $validation = Validator::make($request->all(), [
            'video_type' => 'required',
            'youtube_link' => 'required',
        ]);

        $user = JWTAuth::parseToken()->authenticate();
        $exam_video = ExamVideo::where('user_id', $user->id)->first();
        if($exam_video){
            return  $this->apiResponse->success_response('200','Already uploaded before', 'done'); ;
        }
        ExamVideo::create([
            'user_id' => $user->id,
            'video_link' => $request->youtube_link,
            'video_type' => $request->video_type,
            'exam_id' => 0,
            'is_youtube' => true,
        ]);

        $user_for_email = User::with('zone')->find($user->id);
        SendVideoCongraMail::dispatch($user_for_email);
        return $this->apiResponse->success_response('200','Video Uploaded Successfully', 'done');
    }
    public function submitDriveVideoLink(Request $request){
            $validation = Validator::make($request->all(), [
                'video_type' => 'required',
                'youtube_link' => 'required',
            ]);
            $user = JWTAuth::parseToken()->authenticate();
        $exam_video = ExamVideo::where('user_id', $user->id)->first();
        if($exam_video){
            return  $this->apiResponse->success_response('200','Already uploaded before', 'done'); ;
        }
            ExamVideo::create([
                'user_id' => $user->id,
                'video_link' => $request->youtube_link,
                'video_type' => $request->video_type,
                'exam_id' => 0,
                'is_youtube' => false,
                'is_drive' => true
            ]);

            $user_for_email = User::with('zone')->find($user->id);
            SendVideoCongraMail::dispatch($user_for_email);
            return $this->apiResponse->success_response('200','Video Uploaded Successfully', 'done');
        }
    public function checkVideoExist(Request $request){
        $user = JWTAuth::parseToken()->authenticate();
        $exam = ExamVideo::where('user_id' ,$user->id )->first();
        if($exam){
            return $this->apiResponse->error_response(200,'sdfsdf',$exam);
        }
        else{
            return $this->apiResponse->success_response(400, ' ok', $exam);
        }

    }
}
