@extends('admin.layouts.layout')

@section('title')
    User Edit | Suzuki Admin Panel
@endsection

@section('page-specific-css')
    <link href="{{ asset('plugins/datatables/responsive.bootstrap4.min.css') }}" rel="stylesheet" type="text/css"/>
    <link href="{{ asset('plugins/multiselect/css/multi-select.css') }}" rel="stylesheet" type="text/css"/>
@endsection

@section('page-heading')
    User Details
@endsection

@section('right-side-button')
    <a type="button" class="btn btn-default  waves-effect waves-light" href="{{ route('users.index') }}">
        <span class="btn-label"><i class="fa fa-arrow-circle-left"></i></span>Back
    </a>
@endsection
@section('breadcumb')
    <li class="breadcrumb-item"><a href="{{route('home')}}">Home</a></li>
    <li class="breadcrumb-item active">User Edit</li>
@endsection

@section('content')
    <div class="row">
        <div class="col-md-12">
            @if (count($errors) > 0)
                <div class="alert alert-danger">
                    <strong>Error!</strong> There were some problems with your input.<br><br>
                    <ul>
                        @foreach ($errors->all() as $error)
                            <li>{{ $error }}</li>
                        @endforeach
                    </ul>
                </div>
            @endif
            <div class="card-box">
                <h4 class="m-t-0 header-title">Edit User</h4>
                <form method="post" action="{{ route('users.update',$user->id) }}">
                    {!! method_field('patch') !!}
                    {{ csrf_field() }}
                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="name" class="col-form-label">Name</label> <span class="text-danger">*</span>
                            <input type="text"
                                   class="form-control"
                                   value="{{ $user->name }}"
                                   name="name"
                                   id="name"
                            >
                        </div>
                        <div class="form-group col-md-6">
                            <label for="user_name" class="col-form-label">User ID</label>
                            <input type="text"
                                   class="form-control"
                                   value="{{ $user->user_name }}"
                                   name="user_name"
                                   id="user_name"
                                   disabled
                            >
                        </div>
                        <div class="form-group col-md-6">
                            <label for="email" class="col-form-label">Email</label>
                            <input type="email"
                                   class="form-control"
                                   id="email"
                                   value="{{$user->email }}"
                                   name="email">
                        </div>

                        <div class="form-group col-md-6">
                            <label for="contact_number" class="col-form-label">Contact Number</label><span class="text-danger">*</span>
                            <input type="text"
                                   class="form-control"
                                   id="contact_number"
                                   value="{{ $user->contact_number }}"
                                   name="contact_number">
                        </div>
                        <div class="form-group col-md-6">
                            <label for="password" class="col-form-label">Password</label><span class="text-danger">*</span>
                            <input type="password"
                                   class="form-control"
                                   name="password"
                            >
                        </div>
                        <div class="form-group col-md-6">
                            <label for="password" class="col-form-label">Confirm Password</label><span class="text-danger">*</span>
                            <input type="password"
                                   class="form-control"
                                   name="password_confirmation"
                            >
                        </div>
                        <div class="form-group col-md-6">
                            <label for="permissions" class="col-form-label">Roles</label><span class="text-danger">*</span><br/>
                            <a href='#' id='select-all'>select all</a> &nbsp;&nbsp;&nbsp;
                            <a href='#' id='deselect-all'>deselect all</a>
                            <select multiple="multiple" class="multi-select" id="roles" name="roles[]"
                                    required>
                                <option value=""></option>
                                @foreach($roles as $role)
                                    <option value=" {{ $role->id }}" {{ in_array($role->id,$userRole)?'selected':'' }}> {{ $role->name  }}</option>
                                @endforeach
                            </select>
                        </div>
                        <div class="form-group col-md-6">
                            <button type="submit" class="btn btn-primary pull-right" id="update">Update</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection


@section('page-specific-js')
    @parent
    <script src="{{ asset('plugins/multiselect/js/jquery.multi-select.js') }}"></script>
    <script>
        $("#roles").multiSelect();
    </script>

@endsection